% Code to accompany "Trial size for near-optimal choice between
% surveillance and aggressive treatment: reconsidering MSLT-II"
% by Charles F. Manski and Aleksey Tetenov
% October 2018
% We thank Michael Gmeiner for helpful comments regarding the code.
%
% normal_table.m
%
% This script computes the normal approximation
% to maximum regret of the Empirical Success treatment rule
% for trials of two treatments reported in Table 1
%
% Tested using MATLAB 2018b
% Requires Optimization and Statistics toolboxes
%
% Full runtime: ~ 1 minute (using a desktop with 4-core i7-6700K CPU) 

clear all

% Array of harm (side effect) values
hs = [0:.1:.5]'; nhs = size(hs,1);
% Array of sample sizes
Ns = [10:10:100 150:50:250]'; nNs = size(Ns,1);

fid = fopen('normal_table.csv','w');

for ih=1:nhs
    fprintf(fid,', %0.2f',hs(ih));
end
Rs = zeros(nNs,nhs);

for iN = 1:nNs
    N = Ns(iN);
    fprintf(fid,'\n%0.3d',N);
    
    for ih = 1:nhs
        h = hs(ih);
        Rs(iN,ih) = normal_regret(Ns(iN),hs(ih));        
        fprintf(fid,', %2.6f',Rs(iN,ih));
    end
end
fclose(fid);
