% Code to accompany "Trial size for near-optimal choice between
% surveillance and aggressive treatment: reconsidering MSLT-II"
% by Charles F. Manski and Aleksey Tetenov
% October 2018
% We thank Michael Gmeiner for helpful comments regarding the code.
%
% regret_table.m
%
% This script computes the maximum regret of the Empirical Success 
% treatment rule using simulated annealing
% for trials of two treatments reported in Table 1.
%
% Tested using MATLAB 2018b
% Requires Global Optimization, Optimization, and Statistics toolboxes
%
% Full runtime: ~ 5 hours with MaxIter=10000 in regret.m function
% (using a desktop with 4-core i7-6700K CPU) 

clear all
format long

% Array of harm (side effect) values
hs = [0:.1:.5]'; nhs = size(hs,1);
% Array of sample sizes
Ns = [10:10:100 150:50:250]'; nNs = size(Ns,1);

fid = fopen('regret_table.csv','w');

for ih=1:nhs
    fprintf(fid,', %0.2f',hs(ih));
end
Rs = zeros(nNs,nhs);

for iN = 1:nNs
    N = Ns(iN)
    fprintf(fid,'\n%0.3d',N);
    
    for ih = 1:nhs
        h = hs(ih)
        tic
        Rs(iN,ih) = regret(Ns(iN),hs(ih));
        fprintf(fid,', %2.6f',Rs(iN,ih));
        Rs(iN,ih)
        toc
    end
end
fclose(fid);

