% Code to accompany "Trial size for near-optimal choice between
% surveillance and aggressive treatment: reconsidering MSLT-II"
% by Charles F. Manski and Aleksey Tetenov
% October 2018
% We thank Michael Gmeiner for helpful comments regarding the code.
%
% regret_table_244.m
%
% This script computes the maximum regret of the Empirical Success 
% treatment rule using simulated annealing
% for trials of two treatments with N=240-249 and h = 0.2
% to obtain the minimum sufficient sample size for MSLT-II
%
% Tested using MATLAB 2018b
% Requires Global Optimization, Optimization, and Statistics toolboxes
%
% Full runtime: ~ 3.5 hours with MaxIter=10000 in regret.m function
% (using a desktop with 4-core i7-6700K CPU) 

clear all
format long

h = 0.2;
% Array of sample sizes
Ns = [240:249]'; nNs = size(Ns,1);

fid = fopen('regret_table_244.csv','w');

fprintf(fid,', %0.2f',h);

Rs = zeros(nNs,1);

for iN = 1:nNs
    N = Ns(iN)
    fprintf(fid,'\n%0.3d',N);
    
    tic
    Rs(iN,1) = regret(Ns(iN),h);
    fprintf(fid,', %2.6f',Rs(iN,1));
    Rs(iN,1)
    toc
end
fclose(fid);

